.. bibliography Pynbody Bibliography


References
==========

`Galvagni, M. <http://adsabs.harvard.edu/abs/2012MNRAS.427.1725G>`_, Hayfield, T., Boley, A., Mayer, L., Roskar, R., Saha, P., 2012, MNRAS, 427, 1725

`Pontzen, A. <http://adsabs.harvard.edu/doi/10.1093/mnras/sts529>`_ & Governato, F., *Conserved actions, maximum entropy and dark matter haloes*, 2013, MNRAS, 561

`Pontzen, A. <http://adsabs.harvard.edu/abs/2012MNRAS.421.3464P>`_ & Governato, F. *How supernova feedback turns dark matter cusps into cores*, 2012, MNRAS, 421, 3464

`Roskar, R. <http://adsabs.harvard.edu/abs/2012MNRAS.426.2089R>`_, Debattista V. P., Quinn T. R., Wadsley J., *Radial migration in disc galaxies - I. Transient spiral structure and dynamics*, 2012, MNRAS, 426, 2089

`Roskar, R. <http://adsabs.harvard.edu/abs/2012arXiv1211.1982R>`_, Debattista V. P., Loebman, S., *The Effects of Radial Migration on the Vertical Structure of Galactic Discs*, eprint arXiv:1211.1982

`Stinson, G.S. <http://adsabs.harvard.edu/abs/2013MNRAS.428..129S>`_, Brook, C., Maccio, Wadsley, Quinn, Couchmann, 2013, MNRAS, 428, 129

`Stinson G. S. <http://adsabs.harvard.edu/abs/2012MNRAS.425.1270S>`_, Brook C., Prochaska J. X., Hennawi J., Shen S., Wadsley J., Pontzen A., Couchman H. M. P., Quinn T., Maccio` A. V., Gibson B. K., 2012, MNRAS, p. 3506
